@@ -77,7 +77,7 @@ class MissingTypesForGenericError(Exception):
 
     def __init__(self, field_name: str, annotation):
         message = (
-            f'The type "{annotation}" of the field "{field_name}" '
+            f'The type "{annotation.__name__}" of the field "{field_name}" '
             f"is generic, but no type has been passed"
         )
 
